==> jc-1.4.0.tar.gz: java/net/URLClassLoader__24RemoteURLLoader.h <==
// final class java.net.URLClassLoader$RemoteURLLoader

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fa0b8c8f81887728 java_net_URLClassLoader__24RemoteURLLoader
// @dep_class 10c84e6a4eec2373 java_net_URLClassLoader__24URLLoader

// header file dependencies
// @dep_header java_net_URLClassLoader__24URLLoader

#include "java/net/URLClassLoader__24URLLoader.h"

#ifndef _JC_java_net_URLClassLoader__24RemoteURLLoader_H_
#define _JC_java_net_URLClassLoader__24RemoteURLLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader$object;
struct _jc_java_net_URLClassLoader__24Resource$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_refs	_jc_java_net_URLClassLoader__24RemoteURLLoader$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_nonrefs	_jc_java_net_URLClassLoader__24RemoteURLLoader$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$refs	_jc_java_net_URLClassLoader__24RemoteURLLoader$refs;
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$nonrefs	_jc_java_net_URLClassLoader__24RemoteURLLoader$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object	_jc_java_net_URLClassLoader__24RemoteURLLoader$object;

typedef const struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vmethods	_jc_java_net_URLClassLoader__24RemoteURLLoader$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vtable	_jc_java_net_URLClassLoader__24RemoteURLLoader$vtable;
typedef const struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vtype	_jc_java_net_URLClassLoader__24RemoteURLLoader$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24RemoteURLLoader$method$_init$4f9d67719ed422b4(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object *, struct _jc_java_net_URLClassLoader$object *, struct _jc_java_net_URL$object *);

// Virtual methods
extern struct _jc_java_net_URLClassLoader__24Resource$object *_jc_java_net_URLClassLoader__24RemoteURLLoader$method$getResource$7e88259a529748c1(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24RemoteURLLoader$method_info$getResource$7e88259a529748c1;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vmethods {
	struct _jc_java_net_URLClassLoader__24Resource$object	*(*getResource$7e88259a529748c1)(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24URLLoader$vmethods	java_net_URLClassLoader__24URLLoader;
	_jc_java_net_URLClassLoader__24RemoteURLLoader$vmethods	java_net_URLClassLoader__24RemoteURLLoader;
};

// Vtype
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24RemoteURLLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_refs {
	struct _jc_java_lang_String$object	*protocol;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$refs {
    _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_refs	java_net_URLClassLoader__24RemoteURLLoader;
    _jc_java_net_URLClassLoader__24URLLoader$sub_refs	java_net_URLClassLoader__24URLLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24URLLoader$sub_nonrefs	java_net_URLClassLoader__24URLLoader;
    _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_nonrefs	java_net_URLClassLoader__24RemoteURLLoader;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object {
	_jc_java_net_URLClassLoader__24RemoteURLLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24RemoteURLLoader$vtype	*vtype;
	_jc_java_net_URLClassLoader__24RemoteURLLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24RemoteURLLoader$vtype _jc_java_net_URLClassLoader__24RemoteURLLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24RemoteURLLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24RemoteURLLoader$class_object;

#endif	/* _JC_java_net_URLClassLoader__24RemoteURLLoader_H_ */

==> jc-1.4.6.tar.gz: java/net/URLClassLoader__24RemoteURLLoader.h <==
// final class java.net.URLClassLoader$RemoteURLLoader

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fa0b8c8f81887728 java_net_URLClassLoader__24RemoteURLLoader
// @dep_class 10c84e6a4eec2373 java_net_URLClassLoader__24URLLoader

// header file dependencies
// @dep_header java_net_URLClassLoader__24URLLoader

#include "java/net/URLClassLoader__24URLLoader.h"

#ifndef _JC_java_net_URLClassLoader__24RemoteURLLoader_H_
#define _JC_java_net_URLClassLoader__24RemoteURLLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader$object;
struct _jc_java_net_URLClassLoader__24Resource$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_refs	_jc_java_net_URLClassLoader__24RemoteURLLoader$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_nonrefs	_jc_java_net_URLClassLoader__24RemoteURLLoader$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$refs	_jc_java_net_URLClassLoader__24RemoteURLLoader$refs;
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$nonrefs	_jc_java_net_URLClassLoader__24RemoteURLLoader$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object	_jc_java_net_URLClassLoader__24RemoteURLLoader$object;

typedef const struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vmethods	_jc_java_net_URLClassLoader__24RemoteURLLoader$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vtable	_jc_java_net_URLClassLoader__24RemoteURLLoader$vtable;
typedef const struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vtype	_jc_java_net_URLClassLoader__24RemoteURLLoader$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24RemoteURLLoader$method$_init$4f9d67719ed422b4(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object *, struct _jc_java_net_URLClassLoader$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_net_URLClassLoader__24Resource$object *_jc_java_net_URLClassLoader__24RemoteURLLoader$method$getResource$7e88259a529748c1(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24RemoteURLLoader$method_info$getResource$7e88259a529748c1;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vmethods {
	struct _jc_java_net_URLClassLoader__24Resource$object	*(*getResource$7e88259a529748c1)(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24URLLoader$vmethods	java_net_URLClassLoader__24URLLoader;
	_jc_java_net_URLClassLoader__24RemoteURLLoader$vmethods	java_net_URLClassLoader__24RemoteURLLoader;
};

// Vtype
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24RemoteURLLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_refs {
	struct _jc_java_lang_String$object	*protocol;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$refs {
    _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_refs	java_net_URLClassLoader__24RemoteURLLoader;
    _jc_java_net_URLClassLoader__24URLLoader$sub_refs	java_net_URLClassLoader__24URLLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24URLLoader$sub_nonrefs	java_net_URLClassLoader__24URLLoader;
    _jc_java_net_URLClassLoader__24RemoteURLLoader$sub_nonrefs	java_net_URLClassLoader__24RemoteURLLoader;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object {
	_jc_java_net_URLClassLoader__24RemoteURLLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24RemoteURLLoader$vtype	*vtype;
	_jc_java_net_URLClassLoader__24RemoteURLLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24RemoteURLLoader$vtype _jc_java_net_URLClassLoader__24RemoteURLLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24RemoteURLLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24RemoteURLLoader$class_object;

#endif	/* _JC_java_net_URLClassLoader__24RemoteURLLoader_H_ */
